{ config, pkgs, ... }:

{
  imports =
    [ # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "nixdeploy";

  networking.useNetworkd = true;
  services.resolved.dnssec = "false";
  systemd.network = {
    links."10-eth0" = {
      matchConfig.MACAddress = "5e:1b:ed:a2:91:d1";
      linkConfig.Name = "eth0";
    };
    networks."10-eth0" = {
      matchConfig = {
        Name = "eth0";
      };
      address = [
        "10.42.10.245/24"
        "2a01:4f8:1c0c:8221::245/64"
      ];
      gateway = [
        "10.42.10.1"
        "2a01:4f8:1c0c:8221::1"
      ];
      dns = [
        "10.42.10.8"
        "2a01:4f8:1c0c:8221::8"
      ];
    };
  };

  environment.systemPackages = with pkgs; [ colmena ];

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.05"; # Did you read the comment?

}
