{ config, pkgs, ...}:

{
  networking.vlans."net-leitstelle" = {
    id = 205;
    interface = "ens18";
  };

  networking.interfaces.net-leitstelle.ipv6.addresses = [
    { address = "fe80::1"; prefixLength = 64; }
    { address = "fd00:10:42:205::1"; prefixLength = 64; }
  ];
  networking.interfaces.net-leitstelle.ipv4.addresses = [
    { address = "10.42.205.1"; prefixLength = 24; }
  ];

  services.radvd.config = ''
    interface net-leitstelle {
      AdvSendAdvert on;
      prefix ::/64 {};
      RDNSS 2a01:4f8:1c0c:8221::8 {};
      DNSSL bula22.de {};
    };
  '';

  services.kea.dhcp4 = {
    settings = {
      interfaces-config = {
        interfaces = [ "net-leitstelle" ];
      };
      subnet4 = [
        {
          id = 205;
          subnet = "10.42.205.1/24";
          pools = [
            {
              pool = "10.42.205.100 - 10.42.205.240";
            }
          ];
          option-data = [
            {
              name = "routers";
              data = "10.42.205.1";
            }
          ];
        }
      ];
    };
  };

  clerie.forward-filter.interfaces.net-leitstelle.rules = [
    { incomingInterface = "net-ikt"; }
  ];

  clerie.uplink-selector.interfaces.net-leitstelle.uplink = "uplink-a";
}
