{ config, pkgs, ...}:

{
  networking.vlans."net-verwaltung" = {
    id = 206;
    interface = "ens18";
  };

  networking.interfaces.net-verwaltung.ipv6.addresses = [
    { address = "fe80::1"; prefixLength = 64; }
    { address = "fd00:10:42:206::1"; prefixLength = 64; }
  ];
  networking.interfaces.net-verwaltung.ipv4.addresses = [
    { address = "10.42.206.1"; prefixLength = 24; }
  ];

  services.radvd.config = ''
    interface net-verwaltung {
      AdvSendAdvert on;
      prefix ::/64 {};
      RDNSS 2a01:4f8:1c0c:8221::8 {};
      DNSSL bula22.de {};
    };
  '';

  services.kea.dhcp4 = {
    settings = {
      interfaces-config = {
        interfaces = [ "net-verwaltung" ];
      };
      subnet4 = [
        {
          id = 206;
          subnet = "10.42.206.1/24";
          pools = [
            {
              pool = "10.42.206.100 - 10.42.206.240";
            }
          ];
          option-data = [
            {
              name = "routers";
              data = "10.42.206.1";
            }
          ];
        }
      ];
    };
  };

  clerie.forward-filter.interfaces.net-verwaltung.rules = [
    { incomingInterface = "net-ikt"; }
  ];

  clerie.uplink-selector.interfaces.net-verwaltung.uplink = "uplink-a";
}
