{ config, pkgs, ... }:

{
  imports =
    [
      ./hardware-configuration.nix

      ./nat.nix
      ./ppp.nix
      ./prefix-delegation.nix
      ./uplink-selector.nix

      ./10-net-services.nix
      ./42-net-management.nix
      ./101-net-uplink-a.nix
      ./102-net-uplink-b.nix
      ./151-net-technik-iot.nix
      ./152-net-ikt-toys.nix
      ./201-net-ikt.nix
      ./202-net-technik.nix
      ./203-net-hospital.nix
      ./204-net-zoll.nix
      ./205-net-leitstelle.nix
      ./206-net-verwaltung.nix
      ./208-net-yolo.nix
      ./209-net-infojurte.nix
      ./210-net-internation.nix
      ./211-net-programmtre.nix
      ./212-net-open-office.nix
    ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "router";

  networking.defaultGateway = { address = "10.42.10.25"; interface = "net-services"; };
  networking.defaultGateway6 = { address = "2a01:4f8:1c0c:8221::25"; interface = "net-services"; };

  networking.firewall.checkReversePath = false;

  services.prometheus.exporters.node = {
    enable = true;
    listenAddress = "10.42.10.2";
    openFirewall = true;
  };

  boot.kernel.sysctl = {
    "net.ipv4.conf.all.forwarding" = true;
    "net.ipv4.conf.default.forwarding" = true;

    "net.ipv6.conf.all.accept_ra" = 0;
    "net.ipv6.conf.default.accept_ra" = 0;

    "net.ipv6.conf.all.forwarding" = true;
    "net.ipv6.conf.default.forwarding" = true;
  };

  services.radvd.enable = true;

  services.kea.dhcp4 = {
    enable = true;
    settings = {
      interfaces-config = {
        interfaces = [];
      };
      lease-database = {
        name = "/var/lib/kea/dhcp4.leases";
        persist = true;
        type = "memfile";
      };
      option-data = [
        {
          name = "domain-name-servers";
          data = "10.42.10.8";
        }
        {
          name = "domain-name";
          data = "bula22.de";
        }
      ];
      subnet4 = [];
    };
  };

  clerie.forward-filter.enable = true;

  services.pppd.enable = true;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.05"; # Did you read the comment?

}
